## Header: General Commands ##
# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3
## End of Header: General Commands ##

#
#	Script for Viewing the 70S Ribosome
#	Assembled Thermus Thermophilus Ribosome
#	from Venki Ramakrishna'a lab
#
#_____load files____________________
load files/TT_LSU_Ribosome.pdb
load files/TT_SSU_Ribosome.pdb
disable all
#------------------------------------

#_________redraw main structures_____
as cartoon, TT_LSU_Ribosome
color red, TT_LSU_Ribosome

as cartoon, TT_SSU_Ribosome
color blue, TT_SSU_Ribosome

#-------------------------------------


#_______Separate RNA pieces__________________
create 23S_rRNA, chain A and TT_LSU_Ribosome

create Helix_26A, ( (resi 2009-2017) or (resi 1260-1270) ) and 23S_rRNA

create 16S_rRNA, chain A and TT_SSU_Ribosome

create 5S_rRNA, chain B and TT_LSU_Ribosome

create P_tRNA, chain V and TT_SSU_Ribosome
hide everything, P_tRNA
show stick, P_tRNA


create E_tRNA, chain W and TT_SSU_Ribosome
hide everything, E_tRNA
show stick, E_tRNA


create A_tRNA, chain Y and TT_SSU_Ribosome
hide everything, A_tRNA
show stick, A_tRNA

color red, (*_tRNA and name O*)
color blue, (*_tRNA and name N*)
color orange, (*_tRNA and name P)

color green, (A_tRNA and name C*)
color magenta, (P_tRNA and name C*)
color yellow, (E_tRNA and name C*)


create mRNA, chain X and TT_SSU_Ribosome
color red, mRNA
hide everything, mRNA
show stick, mRNA
color red, (mRNA and name O*)
color blue, (mRNA and name N*)
color orange, (mRNA and name P)
color cyan, (mRNA and name C*)




select AA, P_tRNA and resi 34
select BA, mrna and resi 18

select AB, P_tRNA and resi 35
select BB, mrna and resi 17

select AC, P_tRNA and resi 36
select BC, mrna and resi 16

select AD, A_tRNA and resi 34
select BD, mrna and resi 21

select AE, A_tRNA and resi 35
select BE, mrna and resi 20

select AF, A_tRNA and resi 36
select BF, mrna and resi 19


dist H_bond,AA,BA,3.35
dist H_bond,AB,BB,3.2
dist H_bond,AC,BC,2.8
dist H_bond,AD,BD,3.0
dist H_bond,AE,BE,3.2
dist H_bond,AF,BF,3.2

color black, H_bond

delete AA
delete AB
delete AC
delete AD
delete AE
delete AF

delete BA
delete BB
delete BC
delete BD
delete BE
delete BF

#-----------create decoding center------------------------------

create A_decoding, /16S_rRNA//A/G`530/* or /16S_rRNA//A/A`1493/* or /16S_rRNA//A/A`1492/* or /16S_rRNA//A/C`1054/*
hide everything, A_decoding
show stick, A_decoding
color red, (A_decoding and name O*)
color blue, (A_decoding and name N*)
color orange, (A_decoding and name P)
color wheat, (A_decoding and name C*)


#--------------Make objects for LSU Proteins from 2j01---------------------

create rProtein_L1, TT_LSU_Ribosome and chain C
create rProtein_L2, TT_LSU_Ribosome and chain D
create rProtein_L3, TT_LSU_Ribosome and chain E
create rProtein_L4, TT_LSU_Ribosome and chain F
create rProtein_L5, TT_LSU_Ribosome and chain G
create rProtein_L6, TT_LSU_Ribosome and chain H
create rProtein_L9, TT_LSU_Ribosome and chain I
create rProtein_L10, TT_LSU_Ribosome and chain J
create rProtein_L11, TT_LSU_Ribosome and chain K
create rProtein_L13, TT_LSU_Ribosome and chain N
create rProtein_L14, TT_LSU_Ribosome and chain O
create rProtein_L15, TT_LSU_Ribosome and chain P
create rProtein_L16, TT_LSU_Ribosome and chain Q
create rProtein_L17, TT_LSU_Ribosome and chain R
create rProtein_L18, TT_LSU_Ribosome and chain S
create rProtein_L19, TT_LSU_Ribosome and chain T
create rProtein_L20, TT_LSU_Ribosome and chain U
create rProtein_L21, TT_LSU_Ribosome and chain V
create rProtein_L22, TT_LSU_Ribosome and chain W
create rProtein_L23, TT_LSU_Ribosome and chain X
create rProtein_L24, TT_LSU_Ribosome and chain Y
create rProtein_L25, TT_LSU_Ribosome and chain Z and not resname Mg
create rProtein_L27, TT_LSU_Ribosome and chain 0
create rProtein_L28, TT_LSU_Ribosome and chain 1
create rProtein_L31, TT_LSU_Ribosome and chain 4
create rProtein_L32, TT_LSU_Ribosome and chain 5
create rProtein_L33, TT_LSU_Ribosome and chain 6
create rProtein_L34, TT_LSU_Ribosome and chain 7
create rProtein_L35, TT_LSU_Ribosome and chain 8
create rProtein_L36, TT_LSU_Ribosome and chain 9

#-----Make objects for SSU Proteins from 2j00---------------------

create rProtein_S2, TT_SSU_Ribosome and chain B
create rProtein_S3, TT_SSU_Ribosome and chain C
create rProtein_S4, TT_SSU_Ribosome and chain D
create rProtein_S5, TT_SSU_Ribosome and chain E
create rProtein_S6, TT_SSU_Ribosome and chain F
create rProtein_S7, TT_SSU_Ribosome and chain G
create rProtein_S8, TT_SSU_Ribosome and chain H
create rProtein_S9, TT_SSU_Ribosome and chain I
create rProtein_S10, TT_SSU_Ribosome and chain J
create rProtein_S11, TT_SSU_Ribosome and chain K
create rProtein_S12, TT_SSU_Ribosome and chain L
create rProtein_S13, TT_SSU_Ribosome and chain M
create rProtein_S14, TT_SSU_Ribosome and chain N
create rProtein_S15, TT_SSU_Ribosome and chain O
create rProtein_S16, TT_SSU_Ribosome and chain P
create rProtein_S17, TT_SSU_Ribosome and chain Q
create rProtein_S18, TT_SSU_Ribosome and chain R
create rProtein_S19, TT_SSU_Ribosome and chain S
create rProtein_S20, TT_SSU_Ribosome and chain T
create rProtein_THX, TT_SSU_Ribosome and chain U

#------------------Color Proteins--------------------------------

color orange, rProtein_L*
color purple, rProtein_S*

#---------Mg and ions-----
create 23S_Mg, TT_LSU_Ribosome and chain Z and resname Mg
as spheres, 23S_Mg
color yellow, 23S_Mg

create 16S_Mg, TT_SSU_Ribosome and chain Z and resname Mg
as spheres, 16S_Mg
color yellow, 16S_Mg


#create 16S_Misc, TT_SSU_Ribosome and chain Z and (resname Zn or resname PAR)
as sphere, 16S_Misc and resname ZN
as surface, 16S_Misc and resname PAR
#util.cbaw 16S_Misc

create magnesium, 16S_Mg or 23S_Mg
delete 23S_Mg
delete 16S_Mg

hide everything, Helix_26A
show sticks, Helix_26A
color wheat, name C* and Helix_26A
color blue, name N* and Helix_26A
color red, name O* and Helix_26A
color yellow, name P* and Helix_26A

#---------------------------------------------
set_view (\
     0.919663489,   -0.063383691,   -0.387559026,\
    -0.264605463,    0.629212439,   -0.730804503,\
     0.290178239,    0.774644196,    0.561892033,\
     0.000014782,   -0.000100732, -867.345581055,\
   -38.855552673,  123.068923950,  116.622177124,\
  -8046.585937500, 9781.276367188,  -20.000000000 )